hypothesis: A library for property-based testing
================================================

Description
-----------

A library for property-based testing

License
-------

MPL-2.0

Upstream Contact
----------------

https://pypi.org/project/hypothesis/

